import { select, csv, max, 
        scaleLinear, scaleBand, 
        axisLeft, axisBottom,
        format
       } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = dt => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top:20, right:40, bottom:30, left:200};
  const innerWidth = width - margin.left - margin.right; 
  const innerHeight = height - margin.top - margin.bottom; 
  
  const xScale = scaleLinear()
  	.domain([0, max(dt, xValue)])
  	.range([0,innerWidth]);
  
  const yScale = scaleBand()
  	.domain(dt.map( yValue))
  	.range([0,innerHeight])
  	.padding(0.1);
    
  // define an svg group
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})` );
  
  const xAxisTickFormat = number =>
  	format('.3s')(number).replace('G','B');
  	
  const xAxis = axisBottom( xScale )
  	.tickFormat(xAxisTickFormat);
  
  g.append('g')
    .call(axisLeft( yScale ))
  	.selectAll('.domain, .tick line')
  	.remove();
  
  g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})` )
  	.select('.domain')
  		.remove();
  
  g.selectAll('rect').data(dt)
  	.enter( ).append('rect')
  	.attr('y', d => yScale( yValue(d) ))
  	.attr('width', d => xScale(xValue(d)))
  	.attr('height', yScale.bandwidth)

};

csv('data.csv').then( dta => {
  dta.forEach( d => {
    d.population = +d.population * 1000;
  });
  render( dta );
});
